@@ -61,11 +61,11 @@ fn update_member_deps(dir: &Path, version: &Version) {
         let deps = member_toml.get_mut("dependencies").map(|deps| deps.as_table_mut());
         match deps {
             Some(Some(table)) => {
-                for (name, value) in table.iter_mut() {
-                    if let Some(dep) = value.as_table_mut() {
+                for (name, dep) in table.iter_mut() {
+                    if let Some(dep) = dep.as_table_like_mut() {
                         if let Some(Some(_)) = dep.get("path").map(|dep| dep.as_str()) {
                             // this is a local dependency, so we will need to update the version
-                            dep["version"] = toml_edit::value(version.to_string());
+                            dep.insert("version", toml_edit::value(version.to_string()));
                             dbg!(name);
                         }
                     }
